@@ -15,6 +15,7 @@ from typing import (
 from attr import define, field
 
 from infima_client.core.models.core.date_range import CoreDateRange
+from infima_client.core.models.core.factor_date import CoreFactorDate
 from infima_client.core.models.core.positive_range import CorePositiveRange
 from infima_client.core.models.core.year_range import CoreYearRange
 from infima_client.core.models.mbs.agency import MbsAgency
@@ -38,6 +39,7 @@ class PoolV1FindRequest:
         coupon_range (Union[Unset, CorePositiveRange]):
         coupon_type (Union[Unset, MbsCouponType]):  Default: MbsCouponType.NULL_COUPON_TYPE.
         eligible_tba_only (Union[Unset, bool]):
+        factor_date (Union[Unset, CoreFactorDate]):
         issue_date_range (Union[Unset, CoreDateRange]):
         issue_upb_range (Union[Unset, CorePositiveRange]):
         limit (Union[Unset, int]):
@@ -66,6 +68,7 @@ class PoolV1FindRequest:
     coupon_range: Union[Unset, CorePositiveRange] = UNSET
     coupon_type: Union[Unset, MbsCouponType] = MbsCouponType.NULL_COUPON_TYPE
     eligible_tba_only: Union[Unset, bool] = UNSET
+    factor_date: Union[Unset, CoreFactorDate] = UNSET
     issue_date_range: Union[Unset, CoreDateRange] = UNSET
     issue_upb_range: Union[Unset, CorePositiveRange] = UNSET
     limit: Union[Unset, int] = UNSET
@@ -111,6 +114,10 @@ class PoolV1FindRequest:
             coupon_type = self.coupon_type.value
 
         eligible_tba_only = self.eligible_tba_only
+        factor_date: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.factor_date, Unset):
+            factor_date = self.factor_date.to_dict()
+
         issue_date_range: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.issue_date_range, Unset):
             issue_date_range = self.issue_date_range.to_dict()
@@ -191,6 +198,8 @@ class PoolV1FindRequest:
             field_dict["couponType"] = coupon_type
         if eligible_tba_only is not UNSET:
             field_dict["eligibleTbaOnly"] = eligible_tba_only
+        if factor_date is not UNSET:
+            field_dict["factorDate"] = factor_date
         if issue_date_range is not UNSET:
             field_dict["issueDateRange"] = issue_date_range
         if issue_upb_range is not UNSET:
@@ -275,6 +284,13 @@ class PoolV1FindRequest:
 
         eligible_tba_only = d.pop("eligibleTbaOnly", UNSET)
 
+        _factor_date = d.pop("factorDate", UNSET)
+        factor_date: Union[Unset, CoreFactorDate]
+        if isinstance(_factor_date, Unset):
+            factor_date = UNSET
+        else:
+            factor_date = CoreFactorDate.from_dict(_factor_date)
+
         _issue_date_range = d.pop("issueDateRange", UNSET)
         issue_date_range: Union[Unset, CoreDateRange]
         if isinstance(_issue_date_range, Unset):
@@ -387,6 +403,7 @@ class PoolV1FindRequest:
             coupon_range=coupon_range,
             coupon_type=coupon_type,
             eligible_tba_only=eligible_tba_only,
+            factor_date=factor_date,
             issue_date_range=issue_date_range,
             issue_upb_range=issue_upb_range,
             limit=limit,
