@@ -26,10 +26,12 @@ class PredictionV1GetOneMonthAheadRequest:
     Attributes:
         symbols (List[str]): Pool and cohort names to fetch historical prepayment predictions. Example: 31417EUD1.
         factor_date_range (Union[Unset, CoreFactorDateRange]):
+        return_all_as_ofs (Union[Unset, bool]): Return all as-of dates for a factor date instead of just latest.
     """
 
     symbols: List[str]
     factor_date_range: Union[Unset, CoreFactorDateRange] = UNSET
+    return_all_as_ofs: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -39,6 +41,8 @@ class PredictionV1GetOneMonthAheadRequest:
         if not isinstance(self.factor_date_range, Unset):
             factor_date_range = self.factor_date_range.to_dict()
 
+        return_all_as_ofs = self.return_all_as_ofs
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -48,6 +52,8 @@ class PredictionV1GetOneMonthAheadRequest:
         )
         if factor_date_range is not UNSET:
             field_dict["factorDateRange"] = factor_date_range
+        if return_all_as_ofs is not UNSET:
+            field_dict["returnAllAsOfs"] = return_all_as_ofs
 
         return field_dict
 
@@ -63,9 +69,12 @@ class PredictionV1GetOneMonthAheadRequest:
         else:
             factor_date_range = CoreFactorDateRange.from_dict(_factor_date_range)
 
+        return_all_as_ofs = d.pop("returnAllAsOfs", UNSET)
+
         prediction_v1_get_one_month_ahead_request = cls(
             symbols=symbols,
             factor_date_range=factor_date_range,
+            return_all_as_ofs=return_all_as_ofs,
         )
 
         prediction_v1_get_one_month_ahead_request.additional_properties = d
