@@ -2,7 +2,7 @@ from typing import TYPE_CHECKING, Dict, List, Optional
 
 from infima_client.core.types import Unset
 
-from .utils import DateT, handle_factor_date
+from .utils import DateT, frame_chunker, handle_factor_date
 
 if TYPE_CHECKING:
     from infima_client.client import InfimaClient
