@@ -258,7 +258,7 @@ def simple_dict_to_frame(
     return df
 
 
-MAX_BATCH_SIZE = 1_000
+DEFAULT_CHUNK_SIZE = 1_000
 
 T = TypeVar("T")
 FChunker = Callable[..., Optional[T]]
@@ -270,20 +270,18 @@ class Catter(Protocol):
 
 
 def chunker(
-    col: str, catter: Catter, size: int = MAX_BATCH_SIZE
+    col: str, catter: Catter, chunk_size: int = DEFAULT_CHUNK_SIZE
 ) -> Callable[[FChunker[T]], FChunker[T]]:
-    assert size <= MAX_BATCH_SIZE
-
     def _deco(func: FChunker[Optional[T]]) -> FChunker[Optional[T]]:
         @wraps(func)
         def _chunked_func(*args: Any, **kwargs: Any) -> Optional[T]:
-            chunk_size = kwargs.pop("size", size)
+            size = kwargs.pop("chunk_size", chunk_size) or chunk_size
             items = kwargs.pop(col)
-            it = chunked(items, chunk_size)
+            it = chunked(items, size)
 
             progress: bool = kwargs.pop("progress", False)
-            if progress and len(items) > chunk_size:
-                it = tqdm.tqdm(it, total=math.ceil(len(items) / chunk_size))
+            if progress and len(items) > size:
+                it = tqdm.tqdm(it, total=math.ceil(len(items) / size))
 
             coll: List[T] = []
             for chunk in it:
